#ifndef RANDOMNUMBERS_H
#define RANDOMNUMBERS_H

#include <QtCore>

#define PRODUCT 0
#define SUM 1
#define MINUS 2



class Item {
public:
    int operation;
    int num0, num1, result;
    int mode;

    double frecuency;
    long frec;
    long check;
};

class RandomNumbers
{
public:
    RandomNumbers();

    Item * next ();
    void update (Item * i, int failures, int time);

    void prepare (bool reset = false);

private:
    QList<Item*> numbers;
    int randInt(int low, int high);
    void recalcul ();

	QSettings settings;

};

#endif // RANDOMNUMBERS_H
